==> spip_4.0.4.orig.tar.xz: plugins-dist/mots/lang/mots_oc_va.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=oc_va
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grop important:</b> s’aconselha fòrt de seleccionar un mot clau dins aquel grop.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'los administrators dau sit',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'los redactors',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'los vesitaires dau sit public quand mandan un messatge dins un forum.',

	// I
	'icone_creation_groupe_mots' => 'Crear un novèl grop de mots',
	'icone_creation_mots_cles' => 'Crear un mot clau nòu',
	'icone_modif_groupe_mots' => 'Modificar aquel grop de mots',
	'icone_mots_cles' => 'Mots clau',
	'icone_supprimer_groupe_mots' => 'Suprimir aquel document',
	'icone_voir_tous_mots_cles' => 'Veire totes los mots clau ',
	'info_articles_lies_mot' => 'Los articles liats a aquel mot clau',
	'info_changer_nom_groupe' => 'Chambiar lo nom d’aquel grop:',
	'info_creation_mots_cles' => 'Creatz e configuratz aicí los mots clau dau sit',
	'info_dans_groupe' => 'Dins lo grop:',
	'info_delet_mots_cles' => 'Avètz demandat de suprimir lo mot clau
<b>@titre_mot@</b> (@type_mot@). Aquel mot clau es liat a
 <b>@texte_lie@</b>. Devètz confirmar aquela decision:', # MODIF
	'info_groupe_important' => 'Grop important',
	'info_mots_cles' => 'Los mots clau',
	'info_mots_cles_association' => 'Los mots clau d’aquel grop se pòon associar:',
	'info_oui_suppression_mot_cle' => 'Vòlo suprimir aquel mot clau definitivament.',
	'info_question_mots_cles' => 'Desiratz d’utilizar los mots clau sobre vòstre sit?',
	'info_qui_attribue_mot_cle' => 'Los mots d’aquel grop pòdon èsser atribuits per:',
	'info_retirer_mot' => 'Quitar aqueu mot',
	'info_retirer_mots' => 'Quitar tots los mots ',
	'info_rubriques_liees_mot' => 'Las rubricas liaas a aqueu mot clau',
	'info_selection_un_seul_mot_cle' => 'Se pòt seleccionar mas qu’<b>un mot clau</b> au còp dins aqueu grop.', # MODIF
	'info_supprimer_mot' => 'suprimir aquel mot',
	'info_titre_mot_cle' => 'Nom o títol dau mot clau',
	'info_un_mot' => 'Mas qu’un mot au còp',
	'item_ajout_mots_cles' => 'Autorizar que s’aponda de mots clau als forums',
	'item_non_ajout_mots_cles' => 'Proïbir l’utilizacion dels mots clau dins los forums',
	'item_non_utiliser_config_groupe_mots_cles' => 'Pas utilizar la configuracion avançaa dels grops de mots clau',
	'item_non_utiliser_mots_cles' => 'Pas utilizar los mots clau',
	'item_utiliser_config_groupe_mots_cles' => 'Utilizar la configuracion avançaa dels grops de mots clau',
	'item_utiliser_mots_cles' => 'Utilizar los mots clau',

	// L
	'logo_mot_cle' => 'LÒGO DAU MOT CLAU',

	// T
	'texte_config_groupe_mots_cles' => 'Desiratz, vos, d’activar la configuracion avançaa dels mots clau,
 en indicant per exemple que se pòt seleccionar un mot unenc
 per grop, qu’un grop es important...?', # MODIF
	'texte_mots_cles' => 'Gràcias als mots clau poètz crear de liams tematics entre vòstres articles
  qué que siá lor plaça dins las rubricas. Aquò vos permet
  d’enrichir la navigacion de vòstre sit, e nieus d’utilizar aquelas proprietats 
  per personalizar la presentacion dels articles dins las esqueletas. ',
	'texte_mots_cles_dans_forum' => 'Desiratz, vos, de permetre l’utilizacion dels mots clau, seleccionables per los vesitaires, dins los forums dau sit public? (Atencion: es pro complèxe d’utilizar aquela opcion correctament.)',
	'texte_nouveau_mot' => 'Mot nòu',
	'titre_config_groupe_mots_cles' => 'Configuracion dels grops de mots clau',
	'titre_gauche_mots_edit' => 'MOT NUMÈRO:',
	'titre_mots_cles_dans_forum' => 'Mots clau dins los forums dau sit public',
	'titre_mots_tous' => 'Los mots clau',
	'titre_nouveau_groupe' => 'Grop novèu',
	'titre_page_mots_tous' => 'Mots clau'
);

==> spip_4.3.8+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_oc_va.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=oc_va
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grop important:</b> s’aconselha fòrt de seleccionar un mot clau dins aquel grop.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'los administrators dau sit',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'los redactors',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'los vesitaires dau sit public quand mandan un messatge dins un forum.',

	// I
	'icone_creation_groupe_mots' => 'Crear un novèl grop de mots',
	'icone_creation_mots_cles' => 'Crear un mot clau nòu',
	'icone_modif_groupe_mots' => 'Modificar aquel grop de mots',
	'icone_mots_cles' => 'Mots clau',
	'icone_supprimer_groupe_mots' => 'Suprimir aquel document',
	'icone_voir_tous_mots_cles' => 'Veire totes los mots clau ',
	'info_articles_lies_mot' => 'Los articles liats a aquel mot clau',
	'info_changer_nom_groupe' => 'Chambiar lo nom d’aquel grop:',
	'info_creation_mots_cles' => 'Creatz e configuratz aicí los mots clau dau sit',
	'info_dans_groupe' => 'Dins lo grop:',
	'info_delet_mots_cles' => 'Avètz demandat de suprimir lo mot clau
<b>@titre_mot@</b> (@type_mot@). Aquel mot clau es liat a
 <b>@texte_lie@</b>. Devètz confirmar aquela decision:', # MODIF
	'info_groupe_important' => 'Grop important',
	'info_mots_cles' => 'Los mots clau',
	'info_mots_cles_association' => 'Los mots clau d’aquel grop se pòon associar:',
	'info_oui_suppression_mot_cle' => 'Vòlo suprimir aquel mot clau definitivament.',
	'info_question_mots_cles' => 'Desiratz d’utilizar los mots clau sobre vòstre sit?',
	'info_qui_attribue_mot_cle' => 'Los mots d’aquel grop pòdon èsser atribuits per:',
	'info_retirer_mot' => 'Quitar aqueu mot',
	'info_retirer_mots' => 'Quitar tots los mots ',
	'info_rubriques_liees_mot' => 'Las rubricas liaas a aqueu mot clau',
	'info_selection_un_seul_mot_cle' => 'Se pòt seleccionar mas qu’<b>un mot clau</b> au còp dins aqueu grop.', # MODIF
	'info_supprimer_mot' => 'suprimir aquel mot',
	'info_titre_mot_cle' => 'Nom o títol dau mot clau',
	'info_un_mot' => 'Mas qu’un mot au còp',
	'item_ajout_mots_cles' => 'Autorizar que s’aponda de mots clau als forums',
	'item_non_ajout_mots_cles' => 'Proïbir l’utilizacion dels mots clau dins los forums',
	'item_non_utiliser_config_groupe_mots_cles' => 'Pas utilizar la configuracion avançaa dels grops de mots clau',
	'item_non_utiliser_mots_cles' => 'Pas utilizar los mots clau',
	'item_utiliser_config_groupe_mots_cles' => 'Utilizar la configuracion avançaa dels grops de mots clau',
	'item_utiliser_mots_cles' => 'Utilizar los mots clau',

	// L
	'logo_mot_cle' => 'LÒGO DAU MOT CLAU',

	// T
	'texte_config_groupe_mots_cles' => 'Desiratz, vos, d’activar la configuracion avançaa dels mots clau,
 en indicant per exemple que se pòt seleccionar un mot unenc
 per grop, qu’un grop es important...?', # MODIF
	'texte_mots_cles' => 'Gràcias als mots clau poètz crear de liams tematics entre vòstres articles
  qué que siá lor plaça dins las rubricas. Aquò vos permet
  d’enrichir la navigacion de vòstre sit, e nieus d’utilizar aquelas proprietats 
  per personalizar la presentacion dels articles dins las esqueletas. ',
	'texte_mots_cles_dans_forum' => 'Desiratz, vos, de permetre l’utilizacion dels mots clau, seleccionables per los vesitaires, dins los forums dau sit public? (Atencion: es pro complèxe d’utilizar aquela opcion correctament.)',
	'texte_nouveau_mot' => 'Mot nòu',
	'titre_config_groupe_mots_cles' => 'Configuracion dels grops de mots clau',
	'titre_gauche_mots_edit' => 'MOT NUMÈRO:',
	'titre_mots_cles_dans_forum' => 'Mots clau dins los forums dau sit public',
	'titre_mots_tous' => 'Los mots clau',
	'titre_nouveau_groupe' => 'Grop novèu',
	'titre_page_mots_tous' => 'Mots clau',
];
